==> MediaWikiLanguageExtensionBundle-2017.01.tar.bz2: extensions/cldr/CldrNames/CldrNamesRw.php <==
<?php

$languageNames = [
	'af' => 'Ikinyafurikaneri',
	'am' => 'Inyamuhariki',
	'ar' => 'Icyarabu',
	'as' => 'Icyasamizi',
	'az' => 'Inyazeribayijani',
	'be' => 'Ikibelarusiya',
	'bg' => 'Urunyabuligariya',
	'bn' => 'Ikibengali',
	'br' => 'Inyebiritoni',
	'bs' => 'Inyebosiniya',
	'ca' => 'Igikatalani',
	'cs' => 'Igiceke',
	'cy' => 'Ikigaluwa',
	'da' => 'Ikidaninwa',
	'de' => 'Ikidage',
	'el' => 'Ikigereki',
	'en' => 'Icyongereza',
	'eo' => 'Icyesiperanto',
	'es' => 'Icyesipanyolo',
	'et' => 'Icyesitoniya',
	'eu' => 'Ikibasiki',
	'fa' => 'Inyeperisi',
	'fi' => 'Igifinilande',
	'fil' => 'Ikinyafilipine',
	'fo' => 'Inyefaroyizi',
	'fr' => 'Igifaransa',
	'fy' => 'Igifiriziyani',
	'ga' => 'Ikirilandi',
	'gd' => 'Ikigaluwa cy’Igisweduwa',
	'gl' => 'Ikigalisiya',
	'gn' => 'Inyaguwarani',
	'gu' => 'Inyegujarati',
	'he' => 'Igiheburayo',
	'hi' => 'Igihindi',
	'hr' => 'Igikorowasiya',
	'hu' => 'Igihongiriya',
	'hy' => 'Ikinyarumeniya',
	'ia' => 'Ururimi Gahuzamiryango',
	'id' => 'Ikinyendoziya',
	'ie' => 'Uruhuzandimi',
	'is' => 'Igisilande',
	'it' => 'Igitaliyani',
	'ja' => 'Ikiyapani',
	'jv' => 'Inyejava',
	'ka' => 'Inyejeworujiya',
	'km' => 'Igikambodiya',
	'kn' => 'Igikanada',
	'ko' => 'Igikoreya',
	'ku' => 'Inyekuridishi',
	'ky' => 'Inkerigizi',
	'la' => 'Ikilatini',
	'ln' => 'Ilingala',
	'lo' => 'Ikilawotiyani',
	'lt' => 'Ikilituwaniya',
	'lv' => 'Ikinyaletoviyani',
	'mk' => 'Ikimasedoniyani',
	'ml' => 'Ikimalayalami',
	'mn' => 'Ikimongoli',
	'mr' => 'Ikimarati',
	'ms' => 'Ikimalayi',
	'mt' => 'Ikimaliteze',
	'ne' => 'Ikinepali',
	'nl' => 'Ikinerilande',
	'nn' => 'Inyenoruveji (Nyonorusiki)',
	'no' => 'Ikinoruveji',
	'oc' => 'Inyogusitani',
	'or' => 'Inyoriya',
	'pa' => 'Igipunjabi',
	'pl' => 'Igipolone',
	'ps' => 'Impashito',
	'pt' => 'Igiporutugali',
	'pt-br' => 'Inyeporutigali (Brezili)',
	'pt-pt' => 'Inyeporutigali (Igiporutigali)',
	'ro' => 'Ikinyarumaniya',
	'ru' => 'Ikirusiya',
	'rw' => 'Kinyarwanda',
	'sa' => 'Igisansikiri',
	'sd' => 'Igisindi',
	'sh' => 'Inyeseribiya na Korowasiya',
	'si' => 'Inyesimpaleze',
	'sk' => 'Igisilovaki',
	'sl' => 'Ikinyasiloveniya',
	'so' => 'Igisomali',
	'sq' => 'Icyalubaniya',
	'sr' => 'Igiseribe',
	'st' => 'Inyesesoto',
	'su' => 'Inyesudani',
	'sv' => 'Igisuweduwa',
	'sw' => 'Igiswahili',
	'ta' => 'Igitamili',
	'te' => 'Igitelugu',
	'th' => 'Igitayi',
	'ti' => 'Inyatigirinya',
	'tk' => 'Inyeturukimeni',
	'tlh' => 'Inyekilingoni',
	'tr' => 'Igiturukiya',
	'tw' => 'Inyetuwi',
	'ug' => 'Ikiwiguri',
	'uk' => 'Ikinyayukereni',
	'ur' => 'Inyeyurudu',
	'uz' => 'Inyeyuzubeki',
	'vi' => 'Ikinyaviyetinamu',
	'xh' => 'Inyehawusa',
	'yi' => 'Inyeyidishi',
	'zu' => 'Inyezulu',
];

$countryNames = [
	'RW' => 'Rwanda',
	'TO' => 'Igitonga',
];

==> MediaWikiLanguageExtensionBundle-2019.04.tar.bz2: extensions/cldr/CldrNames/CldrNamesRw.php <==
<?php

$languageNames = [
	'af' => 'Ikinyafurikaneri',
	'am' => 'Inyamuhariki',
	'ar' => 'Icyarabu',
	'as' => 'Icyasamizi',
	'az' => 'Inyazeribayijani',
	'be' => 'Ikibelarusiya',
	'bg' => 'Urunyabuligariya',
	'bn' => 'Ikibengali',
	'br' => 'Inyebiritoni',
	'bs' => 'Inyebosiniya',
	'ca' => 'Igikatalani',
	'cs' => 'Igiceke',
	'cy' => 'Ikigaluwa',
	'da' => 'Ikidaninwa',
	'de' => 'Ikidage',
	'el' => 'Ikigereki',
	'en' => 'Icyongereza',
	'eo' => 'Icyesiperanto',
	'es' => 'Icyesipanyolo',
	'et' => 'Icyesitoniya',
	'eu' => 'Ikibasiki',
	'fa' => 'Inyeperisi',
	'fi' => 'Igifinilande',
	'fil' => 'Ikinyafilipine',
	'fo' => 'Inyefaroyizi',
	'fr' => 'Igifaransa',
	'fy' => 'Igifiriziyani',
	'ga' => 'Ikirilandi',
	'gd' => 'Ikigaluwa cy’Igisweduwa',
	'gl' => 'Ikigalisiya',
	'gn' => 'Inyaguwarani',
	'gu' => 'Inyegujarati',
	'he' => 'Igiheburayo',
	'hi' => 'Igihindi',
	'hr' => 'Igikorowasiya',
	'hu' => 'Igihongiriya',
	'hy' => 'Ikinyarumeniya',
	'ia' => 'Ururimi Gahuzamiryango',
	'id' => 'Ikinyendoziya',
	'ie' => 'Uruhuzandimi',
	'is' => 'Igisilande',
	'it' => 'Igitaliyani',
	'ja' => 'Ikiyapani',
	'jv' => 'Inyejava',
	'ka' => 'Inyejeworujiya',
	'km' => 'Igikambodiya',
	'kn' => 'Igikanada',
	'ko' => 'Igikoreya',
	'ku' => 'Inyekuridishi',
	'ky' => 'Inkerigizi',
	'la' => 'Ikilatini',
	'ln' => 'Ilingala',
	'lo' => 'Ikilawotiyani',
	'lt' => 'Ikilituwaniya',
	'lv' => 'Ikinyaletoviyani',
	'mk' => 'Ikimasedoniya',
	'ml' => 'Ikimalayalami',
	'mn' => 'Ikimongoli',
	'mr' => 'Ikimarati',
	'ms' => 'Ikimalayi',
	'mt' => 'Ikimaliteze',
	'ne' => 'Ikinepali',
	'nl' => 'Ikinerilande',
	'nn' => 'Inyenoruveji (Nyonorusiki)',
	'no' => 'Ikinoruveji',
	'oc' => 'Inyogusitani',
	'or' => 'Inyoriya',
	'pa' => 'Igipunjabi',
	'pl' => 'Igipolone',
	'ps' => 'Impashito',
	'pt' => 'Igiporutugali',
	'pt-br' => 'Inyeporutigali (Brezili)',
	'pt-pt' => 'Inyeporutigali (Igiporutigali)',
	'ro' => 'Ikinyarumaniya',
	'ru' => 'Ikirusiya',
	'rw' => 'Kinyarwanda',
	'sa' => 'Igisansikiri',
	'sd' => 'Igisindi',
	'sh' => 'Inyeseribiya na Korowasiya',
	'si' => 'Inyesimpaleze',
	'sk' => 'Igisilovaki',
	'sl' => 'Ikinyasiloveniya',
	'so' => 'Igisomali',
	'sq' => 'Icyalubaniya',
	'sr' => 'Igiseribe',
	'st' => 'Inyesesoto',
	'su' => 'Inyesudani',
	'sv' => 'Igisuweduwa',
	'sw' => 'Igiswahili',
	'ta' => 'Igitamili',
	'te' => 'Igitelugu',
	'th' => 'Igitayi',
	'ti' => 'Inyatigirinya',
	'tk' => 'Inyeturukimeni',
	'tlh' => 'Inyekilingoni',
	'tr' => 'Igiturukiya',
	'tw' => 'Inyetuwi',
	'ug' => 'Ikiwiguri',
	'uk' => 'Ikinyayukereni',
	'ur' => 'Inyeyurudu',
	'uz' => 'Inyeyuzubeki',
	'vi' => 'Ikinyaviyetinamu',
	'xh' => 'Inyehawusa',
	'yi' => 'Inyeyidishi',
	'zu' => 'Inyezulu',
];

$countryNames = [
	'RW' => 'U Rwanda',
	'TO' => 'Tonga',
];
